pub struct SaveLayerFlags(/* private fields */);Expand description
SaveLayerFlags provides options that may be used in any combination in SaveLayerRec,
defining how layer allocated by Canvas::save_layer() operates. It may be set to zero,
[PRESERVE_LCD_TEXT], [INIT_WITH_PREVIOUS], or both flags.
Implementations
Sourceimpl SaveLayerFlags
impl SaveLayerFlags
pub const PRESERVE_LCD_TEXT: SaveLayerFlags
Sourcepub const INIT_WITH_PREVIOUS: SaveLayerFlags
pub const INIT_WITH_PREVIOUS: SaveLayerFlags
initializes with previous contents
pub const F16_COLOR_TYPE: SaveLayerFlags
Sourceimpl SaveLayerFlags
impl SaveLayerFlags
Sourcepub const fn empty() -> SaveLayerFlags
pub const fn empty() -> SaveLayerFlags
Get a flags value with all bits unset.
Sourcepub const fn all() -> SaveLayerFlags
pub const fn all() -> SaveLayerFlags
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<SaveLayerFlags>
pub const fn from_bits(bits: u32) -> Option<SaveLayerFlags>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> SaveLayerFlags
pub const fn from_bits_truncate(bits: u32) -> SaveLayerFlags
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> SaveLayerFlags
pub const fn from_bits_retain(bits: u32) -> SaveLayerFlags
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<SaveLayerFlags>
pub fn from_name(name: &str) -> Option<SaveLayerFlags>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: SaveLayerFlags) -> bool
pub const fn intersects(&self, other: SaveLayerFlags) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: SaveLayerFlags) -> bool
pub const fn contains(&self, other: SaveLayerFlags) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn insert(&mut self, other: SaveLayerFlags)
pub fn insert(&mut self, other: SaveLayerFlags)
The bitwise or (|) of the bits in self and other.
Sourcepub fn remove(&mut self, other: SaveLayerFlags)
pub fn remove(&mut self, other: SaveLayerFlags)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: SaveLayerFlags)
pub fn toggle(&mut self, other: SaveLayerFlags)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: SaveLayerFlags, value: bool)
pub fn set(&mut self, other: SaveLayerFlags, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: SaveLayerFlags) -> SaveLayerFlags
pub const fn intersection(self, other: SaveLayerFlags) -> SaveLayerFlags
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: SaveLayerFlags) -> SaveLayerFlags
pub const fn union(self, other: SaveLayerFlags) -> SaveLayerFlags
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: SaveLayerFlags) -> SaveLayerFlags
pub const fn difference(self, other: SaveLayerFlags) -> SaveLayerFlags
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: SaveLayerFlags) -> SaveLayerFlags
pub const fn symmetric_difference(self, other: SaveLayerFlags) -> SaveLayerFlags
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> SaveLayerFlags
pub const fn complement(self) -> SaveLayerFlags
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl SaveLayerFlags
impl SaveLayerFlags
Sourcepub const fn iter(&self) -> Iter<SaveLayerFlags>
pub const fn iter(&self) -> Iter<SaveLayerFlags>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<SaveLayerFlags>
pub const fn iter_names(&self) -> IterNames<SaveLayerFlags>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.