pub struct ColorChannelFlag(/* private fields */);Implementations
Sourceimpl ColorChannelFlag
impl ColorChannelFlag
pub const RED: ColorChannelFlag
pub const GREEN: ColorChannelFlag
pub const BLUE: ColorChannelFlag
pub const ALPHA: ColorChannelFlag
pub const GRAY: ColorChannelFlag
pub const GRAY_ALPHA: ColorChannelFlag
pub const RG: ColorChannelFlag
pub const RGB: ColorChannelFlag
pub const RGBA: ColorChannelFlag
Sourceimpl ColorChannelFlag
impl ColorChannelFlag
Sourcepub const fn empty() -> ColorChannelFlag
pub const fn empty() -> ColorChannelFlag
Get a flags value with all bits unset.
Sourcepub const fn all() -> ColorChannelFlag
pub const fn all() -> ColorChannelFlag
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<ColorChannelFlag>
pub const fn from_bits(bits: u32) -> Option<ColorChannelFlag>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> ColorChannelFlag
pub const fn from_bits_truncate(bits: u32) -> ColorChannelFlag
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> ColorChannelFlag
pub const fn from_bits_retain(bits: u32) -> ColorChannelFlag
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<ColorChannelFlag>
pub fn from_name(name: &str) -> Option<ColorChannelFlag>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: ColorChannelFlag) -> bool
pub const fn intersects(&self, other: ColorChannelFlag) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: ColorChannelFlag) -> bool
pub const fn contains(&self, other: ColorChannelFlag) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn insert(&mut self, other: ColorChannelFlag)
pub fn insert(&mut self, other: ColorChannelFlag)
The bitwise or (|) of the bits in self and other.
Sourcepub fn remove(&mut self, other: ColorChannelFlag)
pub fn remove(&mut self, other: ColorChannelFlag)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: ColorChannelFlag)
pub fn toggle(&mut self, other: ColorChannelFlag)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: ColorChannelFlag, value: bool)
pub fn set(&mut self, other: ColorChannelFlag, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: ColorChannelFlag) -> ColorChannelFlag
pub const fn intersection(self, other: ColorChannelFlag) -> ColorChannelFlag
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: ColorChannelFlag) -> ColorChannelFlag
pub const fn union(self, other: ColorChannelFlag) -> ColorChannelFlag
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: ColorChannelFlag) -> ColorChannelFlag
pub const fn difference(self, other: ColorChannelFlag) -> ColorChannelFlag
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(
self,
other: ColorChannelFlag,
) -> ColorChannelFlag
pub const fn symmetric_difference( self, other: ColorChannelFlag, ) -> ColorChannelFlag
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> ColorChannelFlag
pub const fn complement(self) -> ColorChannelFlag
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl ColorChannelFlag
impl ColorChannelFlag
Sourcepub const fn iter(&self) -> Iter<ColorChannelFlag>
pub const fn iter(&self) -> Iter<ColorChannelFlag>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<ColorChannelFlag>
pub const fn iter_names(&self) -> IterNames<ColorChannelFlag>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.