pub struct SurfacePropsFlags(/* private fields */);Implementations
Sourceimpl SurfacePropsFlags
impl SurfacePropsFlags
pub const DEFAULT: SurfacePropsFlags
pub const USE_DEVICE_INDEPENDENT_FONTS: SurfacePropsFlags
pub const DYNAMIC_MSAA: SurfacePropsFlags
pub const ALWAYS_DITHER: SurfacePropsFlags
pub const PRESERVES_TRANSPARENT_DRAWS: SurfacePropsFlags
Sourceimpl SurfacePropsFlags
impl SurfacePropsFlags
Sourcepub const fn empty() -> SurfacePropsFlags
pub const fn empty() -> SurfacePropsFlags
Get a flags value with all bits unset.
Sourcepub const fn all() -> SurfacePropsFlags
pub const fn all() -> SurfacePropsFlags
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<SurfacePropsFlags>
pub const fn from_bits(bits: u32) -> Option<SurfacePropsFlags>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> SurfacePropsFlags
pub const fn from_bits_truncate(bits: u32) -> SurfacePropsFlags
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> SurfacePropsFlags
pub const fn from_bits_retain(bits: u32) -> SurfacePropsFlags
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<SurfacePropsFlags>
pub fn from_name(name: &str) -> Option<SurfacePropsFlags>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: SurfacePropsFlags) -> bool
pub const fn intersects(&self, other: SurfacePropsFlags) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: SurfacePropsFlags) -> bool
pub const fn contains(&self, other: SurfacePropsFlags) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn insert(&mut self, other: SurfacePropsFlags)
pub fn insert(&mut self, other: SurfacePropsFlags)
The bitwise or (|) of the bits in self and other.
Sourcepub fn remove(&mut self, other: SurfacePropsFlags)
pub fn remove(&mut self, other: SurfacePropsFlags)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: SurfacePropsFlags)
pub fn toggle(&mut self, other: SurfacePropsFlags)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: SurfacePropsFlags, value: bool)
pub fn set(&mut self, other: SurfacePropsFlags, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: SurfacePropsFlags) -> SurfacePropsFlags
pub const fn intersection(self, other: SurfacePropsFlags) -> SurfacePropsFlags
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: SurfacePropsFlags) -> SurfacePropsFlags
pub const fn union(self, other: SurfacePropsFlags) -> SurfacePropsFlags
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: SurfacePropsFlags) -> SurfacePropsFlags
pub const fn difference(self, other: SurfacePropsFlags) -> SurfacePropsFlags
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(
self,
other: SurfacePropsFlags,
) -> SurfacePropsFlags
pub const fn symmetric_difference( self, other: SurfacePropsFlags, ) -> SurfacePropsFlags
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> SurfacePropsFlags
pub const fn complement(self) -> SurfacePropsFlags
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl SurfacePropsFlags
impl SurfacePropsFlags
Sourcepub const fn iter(&self) -> Iter<SurfacePropsFlags>
pub const fn iter(&self) -> Iter<SurfacePropsFlags>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<SurfacePropsFlags>
pub const fn iter_names(&self) -> IterNames<SurfacePropsFlags>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.