#[repr(i32)]pub enum PlaceholderAlignment {
Baseline = 0,
AboveBaseline = 1,
BelowBaseline = 2,
Top = 3,
Bottom = 4,
Middle = 5,
}Expand description
Where to vertically align the placeholder relative to the surrounding text.
Variants
Baseline = 0
Match the baseline of the placeholder with the baseline.
AboveBaseline = 1
Align the bottom edge of the placeholder with the baseline such that the placeholder sits on top of the baseline.
BelowBaseline = 2
Align the top edge of the placeholder with the baseline specified in such that the placeholder hangs below the baseline.
Top = 3
Align the top edge of the placeholder with the top edge of the font. When the placeholder is very tall, the extra space will hang from the top and extend through the bottom of the line.
Bottom = 4
Align the bottom edge of the placeholder with the top edge of the font. When the placeholder is very tall, the extra space will rise from the bottom and extend through the top of the line.
Middle = 5
Align the middle of the placeholder with the middle of the text. When the placeholder is very tall, the extra space will grow equally from the top and bottom of the line.