pub struct Flags(/* private fields */);Use the skia_safe::gradient module
Implementations
Sourceimpl Flags
impl Flags
pub const INTERPOLATE_COLORS_IN_PREMUL: Flags
Use the skia_safe::gradient module
Sourceimpl Flags
impl Flags
Sourcepub const fn empty() -> Flags
๐Deprecated since 0.94.0: Use the skia_safe::gradient module
pub const fn empty() -> Flags
Use the skia_safe::gradient module
Get a flags value with all bits unset.
Sourcepub const fn all() -> Flags
๐Deprecated since 0.94.0: Use the skia_safe::gradient module
pub const fn all() -> Flags
Use the skia_safe::gradient module
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u32
๐Deprecated since 0.94.0: Use the skia_safe::gradient module
pub const fn bits(&self) -> u32
Use the skia_safe::gradient module
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<Flags>
๐Deprecated since 0.94.0: Use the skia_safe::gradient module
pub const fn from_bits(bits: u32) -> Option<Flags>
Use the skia_safe::gradient module
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> Flags
๐Deprecated since 0.94.0: Use the skia_safe::gradient module
pub const fn from_bits_truncate(bits: u32) -> Flags
Use the skia_safe::gradient module
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> Flags
๐Deprecated since 0.94.0: Use the skia_safe::gradient module
pub const fn from_bits_retain(bits: u32) -> Flags
Use the skia_safe::gradient module
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Flags>
๐Deprecated since 0.94.0: Use the skia_safe::gradient module
pub fn from_name(name: &str) -> Option<Flags>
Use the skia_safe::gradient module
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesnโt
correspond to any named flag.
Sourcepub const fn is_empty(&self) -> bool
๐Deprecated since 0.94.0: Use the skia_safe::gradient module
pub const fn is_empty(&self) -> bool
Use the skia_safe::gradient module
Whether all bits in self are unset.
Sourcepub const fn is_all(&self) -> bool
๐Deprecated since 0.94.0: Use the skia_safe::gradient module
pub const fn is_all(&self) -> bool
Use the skia_safe::gradient module
Whether all known bits in this flags value are set.
Sourcepub const fn intersects(&self, other: Flags) -> bool
๐Deprecated since 0.94.0: Use the skia_safe::gradient module
pub const fn intersects(&self, other: Flags) -> bool
Use the skia_safe::gradient module
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: Flags) -> bool
๐Deprecated since 0.94.0: Use the skia_safe::gradient module
pub const fn contains(&self, other: Flags) -> bool
Use the skia_safe::gradient module
Whether all set bits in other are also set in self.
Sourcepub fn insert(&mut self, other: Flags)
๐Deprecated since 0.94.0: Use the skia_safe::gradient module
pub fn insert(&mut self, other: Flags)
Use the skia_safe::gradient module
The bitwise or (|) of the bits in self and other.
Sourcepub fn remove(&mut self, other: Flags)
๐Deprecated since 0.94.0: Use the skia_safe::gradient module
pub fn remove(&mut self, other: Flags)
Use the skia_safe::gradient module
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove wonโt truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Flags)
๐Deprecated since 0.94.0: Use the skia_safe::gradient module
pub fn toggle(&mut self, other: Flags)
Use the skia_safe::gradient module
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: Flags, value: bool)
๐Deprecated since 0.94.0: Use the skia_safe::gradient module
pub fn set(&mut self, other: Flags, value: bool)
Use the skia_safe::gradient module
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Flags) -> Flags
๐Deprecated since 0.94.0: Use the skia_safe::gradient module
pub const fn intersection(self, other: Flags) -> Flags
Use the skia_safe::gradient module
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: Flags) -> Flags
๐Deprecated since 0.94.0: Use the skia_safe::gradient module
pub const fn union(self, other: Flags) -> Flags
Use the skia_safe::gradient module
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: Flags) -> Flags
๐Deprecated since 0.94.0: Use the skia_safe::gradient module
pub const fn difference(self, other: Flags) -> Flags
Use the skia_safe::gradient module
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference wonโt truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Flags) -> Flags
๐Deprecated since 0.94.0: Use the skia_safe::gradient module
pub const fn symmetric_difference(self, other: Flags) -> Flags
Use the skia_safe::gradient module
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> Flags
๐Deprecated since 0.94.0: Use the skia_safe::gradient module
pub const fn complement(self) -> Flags
Use the skia_safe::gradient module
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl Flags
impl Flags
Sourcepub const fn iter(&self) -> Iter<Flags>
๐Deprecated since 0.94.0: Use the skia_safe::gradient module
pub const fn iter(&self) -> Iter<Flags>
Use the skia_safe::gradient module
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<Flags>
๐Deprecated since 0.94.0: Use the skia_safe::gradient module
pub const fn iter_names(&self) -> IterNames<Flags>
Use the skia_safe::gradient module
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.